==> nextcloud-15.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tavaliselt saab selle lahendada andes veebiserverile seatete kataloogile \"config\" kirjutusõigused",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "Following databases are supported: %s" : "Toetatud on järgnevad andmebaasid: %s",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Following platforms are supported: %s" : "Toetatud on järgnevad platformid: %s",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help" : "Abi",
    "Apps" : "Rakendused",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Users" : "Kasutajad",
    "Unknown user" : "Tundmatu kasutaja",
    "Basic settings" : "Põhiseaded",
    "Sharing" : "Jagamine",
    "Security" : "Turvalisus",
    "Additional settings" : "Lisaseaded",
    "Personal info" : "Isiklik info",
    "Unlimited" : "Piiramatult",
    "Verifying" : "Kontrollin",
    "Verifying …" : "Kontrollin ...",
    "Verify" : "Kontrolli",
    "%s enter the database username and name." : "%s sisesta andmebaasi kasutajatunnus ja nimi.",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Can't create or write into the data directory %s" : "Ei suuda luua või kirjutada andmete kataloogi %s",
    "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s jagamine ebaõnnestus sest server ei luba %i tüüpi jagamisi",
    "Sharing %s failed, because the file does not exist" : "%s jagamine ebaõnnestus, kuna faili pole olemas",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Sharing %s failed, because you can not share with yourself" : "%s jagamine ebaõnnestus, kuna sa ei saa jagada iseendaga",
    "You need to provide a password to create a public link, only protected links are allowed" : "Avaliku viite tekitamiseks pead sisestama parooli, ainult kaitstud viited on lubatud",
    "Sharing %s failed, because sharing with links is not allowed" : "%s jagamine ebaõnnestus, kuna linkidega jagamine pole lubatud",
    "Not allowed to create a federated share with the same user" : "Liitjagamise loomine sama kasutajaga ei ole lubatud.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Aegumise kuupäeva ei saa määrata. Jagamised ei saa aeguda hiljem kui %s peale jagamist.",
    "Cannot set expiration date. Expiration date is in the past" : "Aegumiskuupäeva ei saa määrata. Aegumise kuupäev on minevikus",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Sharing failed, because the user %s is the original sharer" : "Jagamine ebaõnnestus kuna kasutaja %s on algne jagaja",
    "Sharing %s failed, because resharing is not allowed" : "%s jagamine ebaõnnestus, kuna edasijagamine pole lubatud",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist",
    "Open »%s«" : "Ava »%s«",
    "Can’t increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Files can’t be shared with delete permissions" : "Faile ei saa jagada kustutamise õigusega",
    "Files can’t be shared with create permissions" : "Faile ei saa jagada loomise õigusega",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Can’t set expiration date more than %s days in the future" : "Ei sa määrata aegumise kuupäeva rohkem kui %s päeva tulevikus",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised sümbolid: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "Could not create user" : "Ei saanud kasutajat luua",
    "User disabled" : "Kasutaja deaktiveeritud",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti",
    "Can't read file" : "Faili lugemine ebaõnnestus",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "Cannot write into \"config\" directory" : "Ei saa kirjutada \"config\" kataloogi",
    "Cannot write into \"apps\" directory" : "Ei saa kirjutada \"apps\" kataloogi!",
    "Cannot create \"data\" directory" : "Ei suuda luua \"data\" kataloogi",
    "Setting locale to %s failed" : "Lokaadi %s määramine ebaõnnestus.",
    "Please install one of these locales on your system and restart your webserver." : "Palun paigalda mõni neist lokaatides oma süsteemi ning taaskäivita veebiserver.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav",
    "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Sharing %s failed, because the user %s does not exist" : "%s jagamine ebaõnnestus, kuna kasutajat %s pole olemas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s jagamine ebaõnnestus, kuna kasutaja %s pole ühegi grupi liige, millede liige on %s",
    "Sharing %s failed, because this item is already shared with %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud %s",
    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
    "Sharing %s failed, because the group %s does not exist" : "%s jagamine ebaõnnestus, kuna gruppi %s pole olemas",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s jagamine ebaõnnestus, kuna %s pole grupi %s liige",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s jagamine ebaõnnestus, ei suutnud %s leida, ehk ei ole server hetkel kättesaadav.",
    "Share type %s is not valid for %s" : "Jagamise tüüp %s ei ole õige %s jaoks",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s jagamine ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s jagamine ebaõnnestus, kuna jagamise tagarakend ei suutnud leida %s jaoks lähteallikat",
    "%s shared »%s« with you" : "%s jagas sinuga »%s«",
    "%s shared »%s« with you." : "%s jagas »%s« sinuga.",
    "%s via %s" : "%s läbi %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Rakendust \"%s\" ei saa paigaldada sest järgmised sõltuvused ei ole täidetud: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tavaliselt saab selle lahendada andes veebiserverile seatete kataloogile \"config\" kirjutusõigused",
    "See %s" : "Vaata %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "Following databases are supported: %s" : "Toetatud on järgnevad andmebaasid: %s",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Following platforms are supported: %s" : "Toetatud on järgnevad platformid: %s",
    "Server version %s or higher is required." : "Serveri versioon %s või kõrgem on nõutav.",
    "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "today" : "täna",
    "tomorrow" : "homme",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "next month" : "järgmine kuu",
    "last month" : "viimasel kuul",
    "next year" : "järgmine aasta",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "in a few seconds" : "mõne sekundi jooksul",
    "seconds ago" : "sekundit tagasi",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "__language_name__" : "Eesti",
    "This is an automatically sent email, please do not reply." : "See on automaatselt saadetud e-kiri, palun ära vasta.",
    "Help" : "Abi",
    "Apps" : "Rakendused",
    "Settings" : "Seaded",
    "Log out" : "Logi välja",
    "Users" : "Kasutajad",
    "Unknown user" : "Tundmatu kasutaja",
    "Basic settings" : "Põhiseaded",
    "Sharing" : "Jagamine",
    "Security" : "Turvalisus",
    "Additional settings" : "Lisaseaded",
    "Personal info" : "Isiklik info",
    "%s enter the database username and name." : "%s sisesta andmebaasi kasutajatunnus ja nimi.",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "You need to enter details of an existing account." : "Sa pead sisestama olemasoleva konto andmed.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Can't create or write into the data directory %s" : "Ei suuda luua või kirjutada andmete kataloogi %s",
    "Invalid Federated Cloud ID" : "Vigane liitpilve ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Open »%s«" : "Ava »%s«",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Can’t increase permissions of %s" : "Ei saa %s õigusi suurendada",
    "Files can’t be shared with delete permissions" : "Faile ei saa jagada kustutamise õigusega",
    "Files can’t be shared with create permissions" : "Faile ei saa jagada loomise õigusega",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Can’t set expiration date more than %s days in the future" : "Ei sa määrata aegumise kuupäeva rohkem kui %s päeva tulevikus",
    "Click the button below to open it." : "Vajuta allolevat nuppu, et see avada.",
    "The requested share does not exist anymore" : "Soovitud jagamist enam ei eksisteeri",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Märts.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Juuni.",
    "Jul." : "Juuli.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kasutajanimes on lubatud ainult järgmised sümbolid: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "Username contains whitespace at the beginning or at the end" : "Kasutajanime alguses või lõpus on tühik",
    "Username must not consist of dots only" : "Kasutajanimi ei tohi koosneda ainult punktidest",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "Could not create user" : "Ei saanud kasutajat luua",
    "User disabled" : "Kasutaja deaktiveeritud",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "File is currently busy, please try again later" : "Fail on hetkel kasutuses, proovi hiljem uuesti",
    "Can't read file" : "Faili lugemine ebaõnnestus",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "Cannot write into \"config\" directory" : "Ei saa kirjutada \"config\" kataloogi",
    "Cannot write into \"apps\" directory" : "Ei saa kirjutada \"apps\" kataloogi!",
    "Cannot create \"data\" directory" : "Ei suuda luua \"data\" kataloogi",
    "Setting locale to %s failed" : "Lokaadi %s määramine ebaõnnestus.",
    "Please install one of these locales on your system and restart your webserver." : "Palun paigalda mõni neist lokaatides oma süsteemi ning taaskäivita veebiserver.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Unlimited" : "Piiramatult",
    "Verifying" : "Kontrollin",
    "Verifying …" : "Kontrollin ...",
    "Verify" : "Kontrolli",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s jagamine ebaõnnestus sest server ei luba %i tüüpi jagamisi",
    "Sharing %s failed, because the file does not exist" : "%s jagamine ebaõnnestus, kuna faili pole olemas",
    "Sharing %s failed, because you can not share with yourself" : "%s jagamine ebaõnnestus, kuna sa ei saa jagada iseendaga",
    "Sharing %s failed, because the user %s does not exist" : "%s jagamine ebaõnnestus, kuna kasutajat %s pole olemas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s jagamine ebaõnnestus, kuna kasutaja %s pole ühegi grupi liige, millede liige on %s",
    "Sharing %s failed, because this item is already shared with %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud %s",
    "Sharing %s failed, because this item is already shared with user %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud kasutajaga %s",
    "Sharing %s failed, because the group %s does not exist" : "%s jagamine ebaõnnestus, kuna gruppi %s pole olemas",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s jagamine ebaõnnestus, kuna %s pole grupi %s liige",
    "You need to provide a password to create a public link, only protected links are allowed" : "Avaliku viite tekitamiseks pead sisestama parooli, ainult kaitstud viited on lubatud",
    "Sharing %s failed, because sharing with links is not allowed" : "%s jagamine ebaõnnestus, kuna linkidega jagamine pole lubatud",
    "Not allowed to create a federated share with the same user" : "Liitjagamise loomine sama kasutajaga ei ole lubatud.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s jagamine ebaõnnestus, ei suutnud %s leida, ehk ei ole server hetkel kättesaadav.",
    "Share type %s is not valid for %s" : "Jagamise tüüp %s ei ole õige %s jaoks",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Aegumise kuupäeva ei saa määrata. Jagamised ei saa aeguda hiljem kui %s peale jagamist.",
    "Cannot set expiration date. Expiration date is in the past" : "Aegumiskuupäeva ei saa määrata. Aegumise kuupäev on minevikus",
    "Sharing failed, because the user %s is the original sharer" : "Jagamine ebaõnnestus kuna kasutaja %s on algne jagaja",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s jagamine ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Sharing %s failed, because resharing is not allowed" : "%s jagamine ebaõnnestus, kuna edasijagamine pole lubatud",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s jagamine ebaõnnestus, kuna jagamise tagarakend ei suutnud leida %s jaoks lähteallikat",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist",
    "%s shared »%s« with you" : "%s jagas sinuga »%s«",
    "%s shared »%s« with you." : "%s jagas »%s« sinuga.",
    "%s via %s" : "%s läbi %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Rakendust \"%s\" ei saa paigaldada sest järgmised sõltuvused ei ole täidetud: %s",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav"
},
"nplurals=2; plural=(n != 1);");
